@@ -222,6 +222,12 @@ class DocumentIORegressionTests(TestWithScenarios, TestCase):
         ('everything_in_one_bundle_1_3', {
             'filename': 'everything_in_one_bundle_1.3.json'
         }),
+        ('everything_in_one_bundle_1_4', {
+            'filename': 'everything_in_one_bundle_1.4.json'
+        }),
+        ('everything_in_one_bundle_1_5', {
+            'filename': 'everything_in_one_bundle_1.5.json'
+        }),
     ]
 
     def test_load_document(self):
@@ -386,7 +392,7 @@ class DocumentEvolutionTests_1_2_to_1_3(TestCase):
     def test_evolved_document_is_latest_format(self):
         self.assertFalse(DocumentEvolution.is_latest(self.doc))
         DocumentEvolution.evolve_document(self.doc, one_step=True)
-        self.assertTrue(DocumentEvolution.is_latest(self.doc))
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
 
     def test_evolved_document_is_valid(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
@@ -400,3 +406,69 @@ class DocumentEvolutionTests_1_2_to_1_3(TestCase):
                             'test_documents/evolution_1.3.json'),
             retain_order=False)
         self.assertEqual(self.doc, evolved_doc)
+
+
+class DocumentEvolutionTests_1_3_to_1_4(TestCase):
+
+    def setUp(self):
+        super(DocumentEvolutionTests_1_3_to_1_4, self).setUp()
+        self.fmt, self.doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.3.json'),
+            retain_order=False)
+
+    def test_format_is_changed(self):
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.3")
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.4")
+
+    def test_evolved_document_is_latest_format(self):
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
+
+    def test_evolved_document_is_valid(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(DocumentIO.check(self.doc),
+                         "Dashboard Bundle Format 1.4")
+
+    def test_evoloved_document_is_what_we_expect(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        fmt, evolved_doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.4.json'),
+            retain_order=False)
+        self.assertEqual(self.doc, evolved_doc)
+
+
+class DocumentEvolutionTests_1_4_to_1_5(TestCase):
+
+    def setUp(self):
+        super(DocumentEvolutionTests_1_4_to_1_5, self).setUp()
+        self.fmt, self.doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.4.json'),
+            retain_order=False)
+
+    def test_format_is_changed(self):
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.4")
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.5")
+
+    def test_evolved_document_is_latest_format(self):
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertTrue(DocumentEvolution.is_latest(self.doc))
+
+    def test_evolved_document_is_valid(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(DocumentIO.check(self.doc),
+                         "Dashboard Bundle Format 1.5")
+
+    def test_evoloved_document_is_what_we_expect(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        fmt, evolved_doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.5.json'),
+            retain_order=False)
+        self.assertEqual(self.doc, evolved_doc)
